( cd usr/lib/mono/gtksourceview-sharp-2.0 ; rm -rf gtksourceview-sharp.dll )
( cd usr/lib/mono/gtksourceview-sharp-2.0 ; ln -sf ../gac/gtksourceview-sharp/1.0.0.2__35e10195dab3c99f/gtksourceview-sharp.dll gtksourceview-sharp.dll )
